translate.tools.poclean

Package translate :: Package tools :: Module poclean |
[hide private]
[frames] | no frames]

# Module poclean

source code

Produces a clean file from an unclean file (Trados/Wordfast) by stripping out the tw4win indicators.

This does not convert an RTF file to PO/XLIFF, but produces the target file with only the target text in from a text version of the RTF.

Functions | [hide private]
cleanunit(unit) cleans the targets in the given unit | source code
cleanfile(thefile) cleans the given file | source code
runclean(inputfile, outputfile, templatefile) reads in inputfile, cleans, writes to outputfile | source code
main() | source code

Variables | [hide private]
| tw4winre = `re.compile(r'`(?ms)`\{0>.`*?`<\}\d`{1,3}`\{>`(`.`*?``)`<0\}')`
| __package__ = ``'``translate.tools``'``

Imports: re, factory, multistring